"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var stream_1 = require("stream");
var platform_locator_1 = require("../platform/platform-locator");
var log_request_1 = require("../platform/requests/log-request");
var PlatformStream = (function (_super) {
    __extends(PlatformStream, _super);
    function PlatformStream(cfg) {
        _super.call(this);
        console.log("Instantiating a platform-stream");
        // Establish underlying connection to the platform
        this.logService = platform_locator_1.PlatformLocator.connect(cfg).then(function (platform) {
            // Retrieve a logging service matching our needs. For performance,
            // we pre-resolve the service instead of relying on the platform capacity
            // to resolve services based on requests
            return platform.resolveService({
                group: 'system:monitor',
                action: "log"
            });
        }).catch(function (error) {
            console.error("Unable to resolve service system:monitor", error);
        });
    }
    PlatformStream.prototype._write = function (chunk, encoding, next) {
        if (this.logService) {
            // Record log using our logging service
            return this.logService.then(function (service) {
                return service.exec(new log_request_1.LogRequest(chunk, encoding));
            })
                .then(function (result) {
                next(null, result);
                return null;
            }).catch(next);
        }
        else {
            console.log("OFFLINE: " + chunk.toString('utf8'));
        }
    };
    return PlatformStream;
}(stream_1.Writable));
exports.PlatformStream = PlatformStream;

//# sourceMappingURL=platform-stream.js.map
